"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const react_1 = tslib_1.__importStar(require("react"));
const ProductCard_1 = tslib_1.__importDefault(require("../ProductCard"));
const Filters_1 = tslib_1.__importDefault(require("../Filters"));
const Groups_1 = tslib_1.__importDefault(require("../Groups"));
const FiltersIcon_1 = tslib_1.__importDefault(require("../Filters/FiltersIcon"));
const MobileModal_1 = tslib_1.__importDefault(require("../MobileModal"));
const Sort_1 = tslib_1.__importDefault(require("../Sort"));
const Pagination_1 = tslib_1.__importDefault(require("../Pagination"));
const ZeroResults_1 = tslib_1.__importDefault(require("./ZeroResults/ZeroResults"));
const Spinner_1 = tslib_1.__importDefault(require("../Spinner"));
const reducer_1 = require("./reducer");
const utils_1 = require("../../utils");
const useCioPlpContext_1 = require("../../hooks/useCioPlpContext");
const useCioPlp_1 = tslib_1.__importDefault(require("../../hooks/useCioPlp"));
const Breadcrumbs_1 = tslib_1.__importDefault(require("../Breadcrumbs"));
function CioPlpGrid(props) {
    var _a, _b, _c, _d, _e;
    const { spinner, initialSearchResponse, initialBrowseResponse, filterConfigs, sortConfigs, paginationConfigs, groupsConfigs, children, } = props;
    const [isFilterOpen, setIsFilterOpen] = (0, react_1.useState)(false);
    const plpData = (0, useCioPlp_1.default)({
        initialSearchResponse,
        initialBrowseResponse,
    });
    const { isSearchPage, isBrowsePage, searchQuery, browseFilterValue, data, status, filters, sort, plpContainerCnstrcDataAttributes, } = plpData;
    const { callbacks: { onRedirect = (redirectUrl) => window.location.replace(redirectUrl) }, } = (0, useCioPlpContext_1.useCioPlpContext)();
    if ((0, utils_1.isPlpSearchDataRedirect)(data)) {
        const redirectUrl = data.redirect.data.url;
        if (onRedirect) {
            onRedirect(redirectUrl);
        }
        return null;
    }
    if (!isSearchPage && !isBrowsePage) {
        // Render Zero results page in the case where no query is provided
        // TODO: Allow customers to override default page
        return react_1.default.createElement(ZeroResults_1.default, null);
    }
    let renderHeader;
    if (isSearchPage) {
        renderHeader = (react_1.default.createElement("span", { className: 'cio-products-header-title' },
            react_1.default.createElement("b", null, (_a = data === null || data === void 0 ? void 0 : data.response) === null || _a === void 0 ? void 0 : _a.totalNumResults),
            " results",
            searchQuery && (react_1.default.createElement(react_1.default.Fragment, null,
                "\u00A0for ",
                react_1.default.createElement("b", null,
                    "\"",
                    searchQuery,
                    "\"")))));
    }
    else if (isBrowsePage && (data === null || data === void 0 ? void 0 : data.request.browse_filter_name) === 'group_id') {
        renderHeader = (react_1.default.createElement(Breadcrumbs_1.default, { groups: (data === null || data === void 0 ? void 0 : data.response.groups) || [], filterValue: browseFilterValue || '' }));
    }
    return (react_1.default.createElement(react_1.default.Fragment, null, typeof children === 'function' ? (children(plpData)) : (react_1.default.createElement(react_1.default.Fragment, null,
        status === reducer_1.RequestStatus.FETCHING && (spinner || react_1.default.createElement(Spinner_1.default, null)),
        status !== reducer_1.RequestStatus.FETCHING && data && (react_1.default.createElement(react_1.default.Fragment, null, ((_c = (_b = data.response) === null || _b === void 0 ? void 0 : _b.results) === null || _c === void 0 ? void 0 : _c.length) ? (react_1.default.createElement("div", { className: 'cio-plp-grid' },
            react_1.default.createElement("div", { className: 'cio-filters-container cio-large-screen-only' },
                isSearchPage && react_1.default.createElement(Groups_1.default, Object.assign({ groups: data.response.groups }, groupsConfigs)),
                react_1.default.createElement(Filters_1.default, Object.assign({ facets: filters.facets }, filterConfigs))),
            react_1.default.createElement("div", Object.assign({ className: 'cio-products-container' }, plpContainerCnstrcDataAttributes),
                react_1.default.createElement("div", { className: 'cio-products-header-container' },
                    react_1.default.createElement("div", { className: 'cio-mobile-products-header-wrapper cio-mobile-only' }, renderHeader),
                    react_1.default.createElement("div", { className: 'cio-products-header-wrapper' },
                        react_1.default.createElement("button", { type: 'button', className: 'cio-filters-modal-button cio-mobile-only', onClick: () => setIsFilterOpen(!isFilterOpen) },
                            FiltersIcon_1.default,
                            "Filters"),
                        react_1.default.createElement("span", { className: 'cio-large-screen-only' }, renderHeader),
                        react_1.default.createElement(Sort_1.default, Object.assign({ sortOptions: sort.sortOptions, isOpen: false }, sortConfigs)))),
                react_1.default.createElement("div", { className: 'cio-product-tiles-container' },
                    react_1.default.createElement(MobileModal_1.default, { isOpen: isFilterOpen, setIsOpen: setIsFilterOpen },
                        react_1.default.createElement(Filters_1.default, { facets: filters.facets })), (_e = (_d = data.response) === null || _d === void 0 ? void 0 : _d.results) === null || _e === void 0 ? void 0 :
                    _e.map((item) => (react_1.default.createElement("div", { className: 'cio-product-tile', key: item.itemId },
                        react_1.default.createElement(ProductCard_1.default, { key: item.itemId, item: item }))))),
                react_1.default.createElement("div", { className: 'cio-pagination-container' },
                    react_1.default.createElement(Pagination_1.default, Object.assign({ totalNumResults: data.response.totalNumResults, resultsPerPage: data.response.numResultsPerPage }, paginationConfigs)))))) : (react_1.default.createElement("div", Object.assign({}, plpContainerCnstrcDataAttributes),
            react_1.default.createElement(ZeroResults_1.default, null)))))))));
}
exports.default = CioPlpGrid;
