"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.initFunction = exports.requestReducer = exports.initialState = exports.RequestType = exports.RequestStatus = void 0;
const transformers_1 = require("../../utils/transformers");
var RequestStatus;
(function (RequestStatus) {
    RequestStatus["STALE"] = "stale";
    RequestStatus["FETCHING"] = "fetching";
    RequestStatus["SUCCESS"] = "success";
    RequestStatus["ERROR"] = "error";
})(RequestStatus = exports.RequestStatus || (exports.RequestStatus = {}));
var RequestType;
(function (RequestType) {
    RequestType["SEARCH"] = "search";
    RequestType["BROWSE"] = "browse";
})(RequestType = exports.RequestType || (exports.RequestType = {}));
exports.initialState = {
    status: RequestStatus.STALE,
    search: null,
    browse: null,
};
function requestReducer(state, action) {
    switch (action.type) {
        case RequestStatus.FETCHING: {
            return Object.assign(Object.assign({}, state), { status: RequestStatus.FETCHING });
        }
        case RequestStatus.SUCCESS: {
            const { payload, requestType } = action;
            let search = null;
            let browse = null;
            if (payload) {
                if (requestType === RequestType.SEARCH) {
                    search = (0, transformers_1.transformSearchResponse)(payload.rawApiResponse);
                }
                else if (requestType === RequestType.BROWSE) {
                    browse = (0, transformers_1.transformBrowseResponse)(payload.rawApiResponse);
                }
            }
            return Object.assign(Object.assign({}, state), { status: RequestStatus.SUCCESS, search,
                browse });
        }
        case RequestStatus.ERROR: {
            return Object.assign(Object.assign({}, state), { status: RequestStatus.ERROR, message: action.payload });
        }
        default: {
            return state;
        }
    }
}
exports.requestReducer = requestReducer;
function initFunction(defaultState, initialSearchResponse, initialBrowseResponse) {
    if (initialSearchResponse) {
        return {
            status: RequestStatus.STALE,
            search: (0, transformers_1.transformSearchResponse)(initialSearchResponse),
            browse: null,
        };
    }
    if (initialBrowseResponse) {
        return {
            status: RequestStatus.STALE,
            search: null,
            browse: (0, transformers_1.transformBrowseResponse)(initialBrowseResponse),
        };
    }
    return defaultState;
}
exports.initFunction = initFunction;
