"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const react_1 = tslib_1.__importStar(require("react"));
const classnames_1 = tslib_1.__importDefault(require("classnames"));
/**
 * For consistency. Utility Function to extract value from an event.
 * @param e Change Event on an input element.
 * @returns Parsed float value of the new input value or NaN if empty
 */
function getValueFromOnChangeEvent(e) {
    var _a;
    const parsedValue = parseFloat((_a = e === null || e === void 0 ? void 0 : e.target) === null || _a === void 0 ? void 0 : _a.value);
    if (Number.isNaN(parsedValue)) {
        return '';
    }
    return parsedValue;
}
function FilterRangeSlider(props) {
    var _a, _b;
    const { rangedFacet: facet, modifyRequestRangeFilter, isCollapsed, sliderStep = 0.1 } = props;
    const visibleTrack = (0, react_1.useRef)(null);
    const [selectedTrackStyles, setSelectedTrackStyles] = (0, react_1.useState)({});
    const [minValue, setMinValue] = (0, react_1.useState)(facet.min);
    const [maxValue, setMaxValue] = (0, react_1.useState)(facet.max);
    const [inputMinValue, setInputMinValue] = (0, react_1.useState)(((_a = facet.status) === null || _a === void 0 ? void 0 : _a.min) || facet.min);
    const [inputMaxValue, setInputMaxValue] = (0, react_1.useState)(((_b = facet.status) === null || _b === void 0 ? void 0 : _b.max) || facet.max);
    const [filterRange, setFilterRange] = (0, react_1.useState)('');
    const [isModified, setIsModified] = (0, react_1.useState)(false);
    const isValidMinValue = (value) => typeof value !== 'string' && value < maxValue && value >= facet.min;
    const isValidMaxValue = (value) => typeof value !== 'string' && value > minValue && value <= facet.max;
    const onMinSliderMove = (event) => {
        const sliderValue = getValueFromOnChangeEvent(event);
        if (isValidMinValue(sliderValue)) {
            setMinValue(sliderValue);
            setInputMinValue(sliderValue);
            setIsModified(true);
        }
    };
    const onMaxSliderMove = (event) => {
        const sliderValue = getValueFromOnChangeEvent(event);
        if (isValidMaxValue(sliderValue)) {
            setMaxValue(sliderValue);
            setInputMaxValue(sliderValue);
            setIsModified(true);
        }
    };
    const onSliderMoveEnd = () => {
        const newRange = `${minValue}-${maxValue}`;
        modifyRequestRangeFilter(newRange);
    };
    const onMaxInputValueChange = (event) => {
        const inputValue = getValueFromOnChangeEvent(event);
        setInputMaxValue(inputValue);
        if (isValidMaxValue(inputValue)) {
            setMaxValue(inputValue);
            setIsModified(true);
        }
    };
    const onMinInputValueChange = (event) => {
        const inputValue = getValueFromOnChangeEvent(event);
        setInputMinValue(inputValue);
        if (isValidMinValue(inputValue)) {
            setMinValue(inputValue);
            setIsModified(true);
        }
    };
    const onInputBlurApplyFilter = () => {
        if (isModified && isValidMaxValue(inputMaxValue) && isValidMinValue(inputMinValue)) {
            modifyRequestRangeFilter(filterRange);
        }
    };
    const onTrackClick = (event) => {
        if (visibleTrack.current === null)
            return;
        if (event.target !== visibleTrack.current)
            return;
        const totalWidth = visibleTrack.current.offsetWidth;
        const clickedX = event.nativeEvent.offsetX;
        const selectedValue = Math.round((clickedX / totalWidth) * (facet.max - facet.min)) + facet.min;
        const distMinToClicked = Math.abs(selectedValue - minValue);
        const distMaxToClicked = Math.abs(selectedValue - maxValue);
        if (distMinToClicked <= distMaxToClicked) {
            const newRange = `${selectedValue}-${maxValue}`;
            setMinValue(selectedValue);
            setInputMinValue(selectedValue);
            modifyRequestRangeFilter(newRange);
        }
        else {
            const newRange = `${minValue}-${selectedValue}`;
            setMaxValue(selectedValue);
            setInputMaxValue(selectedValue);
            modifyRequestRangeFilter(newRange);
        }
        setIsModified(true);
    };
    // Update internal state
    (0, react_1.useEffect)(() => {
        if (facet.status.min && !isModified) {
            // Initial state
            setMinValue(facet.status.min);
            setMaxValue(facet.status.max);
            setFilterRange(`${facet.status.min}-${facet.status.max}`);
        }
        else if (isModified) {
            // Future updates
            setFilterRange(`${minValue}-${maxValue}`);
        }
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [minValue, maxValue, facet]);
    // Update selected track styles
    (0, react_1.useEffect)(() => {
        const trackLen = facet.max - facet.min;
        const rebasedStartValue = minValue - facet.min;
        const startPercentage = ((100 * rebasedStartValue) / trackLen).toFixed(2);
        const widthPercentage = ((100 * (maxValue - minValue)) / trackLen).toFixed(2);
        setSelectedTrackStyles({ left: `${startPercentage}%`, width: `${widthPercentage}%` });
    }, [minValue, maxValue, facet]);
    return (react_1.default.createElement("div", { className: (0, classnames_1.default)({
            'cio-collapsible-wrapper': true,
            'cio-collapsible-is-open': !isCollapsed,
        }) },
        react_1.default.createElement("div", { className: 'cio-collapsible-inner' },
            react_1.default.createElement("div", { className: 'cio-filter-ranged-slider' },
                react_1.default.createElement("div", { className: 'cio-slider-inputs' },
                    react_1.default.createElement("span", { className: 'cio-slider-input cio-slider-input-min' },
                        react_1.default.createElement("span", { className: 'cio-slider-input-prefix' }, "from "),
                        react_1.default.createElement("input", { required: true, type: 'number', value: inputMinValue, onChange: onMinInputValueChange, onBlur: onInputBlurApplyFilter, placeholder: facet.min.toString(), min: facet.min, max: maxValue, step: sliderStep })),
                    react_1.default.createElement("div", { className: 'cio-slider-input cio-slider-input-max' },
                        react_1.default.createElement("span", { className: 'cio-slider-input-prefix' }, "to "),
                        react_1.default.createElement("input", { required: true, type: 'number', value: inputMaxValue, onChange: onMaxInputValueChange, onBlur: onInputBlurApplyFilter, placeholder: facet.max.toString(), min: minValue, max: facet.max, step: sliderStep }))),
                react_1.default.createElement("div", { className: 'cio-doubly-ended-slider', ref: visibleTrack, role: 'presentation', onClick: (e) => onTrackClick(e) },
                    react_1.default.createElement("div", { className: 'cio-slider-track-selected', style: selectedTrackStyles }),
                    react_1.default.createElement("input", { className: 'cio-min-slider', type: 'range', step: sliderStep, min: facet.min, max: facet.max, value: minValue, onChange: onMinSliderMove, onMouseUp: onSliderMoveEnd }),
                    react_1.default.createElement("input", { className: 'cio-max-slider', type: 'range', step: sliderStep, min: facet.min, max: facet.max, value: maxValue, onChange: onMaxSliderMove, onMouseUp: onSliderMoveEnd }))))));
}
exports.default = FilterRangeSlider;
