"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
/* eslint-disable react/no-array-index-key */
const react_1 = tslib_1.__importStar(require("react"));
const usePagination_1 = tslib_1.__importDefault(require("../../hooks/usePagination"));
function Pagination(props) {
    const { totalNumResults, resultsPerPage, windowSize = 5, children } = props;
    const [pageWindowSize, setPageWindowSize] = (0, react_1.useState)(windowSize);
    const pagesRef = (0, react_1.useRef)(null);
    const { currentPage, goToPage, nextPage, prevPage, pages, totalPages } = (0, usePagination_1.default)({
        totalNumResults,
        resultsPerPage,
        windowSize: pageWindowSize,
    });
    (0, react_1.useEffect)(() => {
        setPageWindowSize(windowSize);
    }, [windowSize]);
    // Calculate windowSize on resize event
    (0, react_1.useEffect)(() => {
        const resize = () => {
            var _a, _b;
            const parentSize = Number((_b = (_a = pagesRef.current) === null || _a === void 0 ? void 0 : _a.parentElement) === null || _b === void 0 ? void 0 : _b.clientWidth) || window.innerWidth;
            setPageWindowSize(Math.max(1, Math.min(Math.floor(parentSize / 60) - 4, windowSize)));
        };
        resize();
        window.addEventListener('resize', resize);
        return () => {
            window.removeEventListener('resize', resize);
        };
    }, [windowSize]);
    return (react_1.default.createElement(react_1.default.Fragment, null, typeof children === 'function' ? (children({
        currentPage,
        goToPage,
        nextPage,
        pages,
        prevPage,
        totalPages,
    })) : (react_1.default.createElement("div", { ref: pagesRef, className: 'cio-pagination' },
        react_1.default.createElement("button", { onClick: () => prevPage(), type: 'button', "data-testid": 'cio-pagination-prev-button' }, "<"),
        pages.map((page, i) => (react_1.default.createElement("button", { onClick: () => goToPage(page), type: 'button', key: `${page},${i}`, className: currentPage === page ? 'selected' : '' }, page === -1 ? react_1.default.createElement("span", null, "...") : page))),
        react_1.default.createElement("button", { onClick: () => nextPage(), type: 'button', "data-testid": 'cio-pagination-next-button' }, ">")))));
}
exports.default = Pagination;
Pagination.defaultProps = {
    resultsPerPage: 20,
    windowSize: 5,
};
