"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const react_1 = tslib_1.__importDefault(require("react"));
const useCioPlpContext_1 = require("../../hooks/useCioPlpContext");
const callbacks_1 = require("../../hooks/callbacks");
const ProductSwatch_1 = tslib_1.__importDefault(require("../ProductSwatch"));
const useProduct_1 = tslib_1.__importDefault(require("../../hooks/useProduct"));
const utils_1 = require("../../utils");
/**
 * ProductCard component that has Constructor tracking built-in.
 */
function ProductCard(props) {
    const { item, children } = props;
    const state = (0, useCioPlpContext_1.useCioPlpContext)();
    const productInfo = (0, useProduct_1.default)({ item });
    const { productSwatch, itemName, itemPrice, itemImageUrl, itemUrl } = productInfo;
    if (!state) {
        throw new Error('This component is meant to be used within the CioPlp provider.');
    }
    if (!item.data || !item.itemId || !item.itemName) {
        throw new Error('data, itemId, or itemName are required.');
    }
    const client = state.cioClient;
    const onAddToCart = (0, callbacks_1.useOnAddToCart)(client, state.callbacks.onAddToCart);
    const { formatPrice } = state.formatters;
    const onClick = (0, callbacks_1.useOnProductCardClick)(client, state.callbacks.onProductCardClick);
    const cnstrcData = (0, utils_1.getProductCardCnstrcDataAttributes)(productInfo);
    return (react_1.default.createElement(react_1.default.Fragment, null, typeof children === 'function' ? (children({
        item,
        productInfo,
        formatPrice,
        onAddToCart,
        onClick,
        productCardCnstrcDataAttributes: cnstrcData,
    })) : (react_1.default.createElement("a", Object.assign({}, cnstrcData, { className: 'cio-product-card', href: itemUrl, onClick: (e) => { var _a; return onClick(e, item, (_a = productSwatch === null || productSwatch === void 0 ? void 0 : productSwatch.selectedVariation) === null || _a === void 0 ? void 0 : _a.variationId); } }),
        react_1.default.createElement("div", { className: 'cio-image-container' },
            react_1.default.createElement("img", { alt: itemName, src: itemImageUrl, className: 'cio-image' })),
        react_1.default.createElement("div", { className: 'cio-content' },
            Number(itemPrice) >= 0 && (react_1.default.createElement("div", { className: 'cio-item-price' }, formatPrice(itemPrice))),
            react_1.default.createElement("div", { className: 'cio-item-name' }, itemName),
            productSwatch && react_1.default.createElement(ProductSwatch_1.default, { swatchObject: productSwatch })),
        react_1.default.createElement("button", { className: 'cio-add-to-cart-button', type: 'button', onClick: (e) => { var _a; return onAddToCart(e, item, itemPrice, (_a = productSwatch === null || productSwatch === void 0 ? void 0 : productSwatch.selectedVariation) === null || _a === void 0 ? void 0 : _a.variationId); } }, "Add to Cart")))));
}
exports.default = ProductCard;
