"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const react_1 = require("react");
const useCioPlpContext_1 = require("./useCioPlpContext");
const useRequestConfigs_1 = tslib_1.__importDefault(require("./useRequestConfigs"));
const transformers_1 = require("../utils/transformers");
const utils_1 = require("../utils");
const useFirstRender_1 = tslib_1.__importDefault(require("./useFirstRender"));
const reducer_1 = require("../components/CioPlpGrid/reducer");
const fetchBrowseResults = (client, filterName, filterValue, browseParameters, dispatch) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    dispatch({
        type: reducer_1.RequestStatus.FETCHING,
    });
    try {
        const res = yield client.browse.getBrowseResults(filterName, filterValue, browseParameters);
        dispatch({
            type: reducer_1.RequestStatus.SUCCESS,
            requestType: reducer_1.RequestType.BROWSE,
            payload: (0, transformers_1.transformBrowseResponse)(res),
        });
    }
    catch (err) {
        if (err instanceof Error) {
            dispatch({
                type: reducer_1.RequestStatus.ERROR,
                payload: err.message,
            });
        }
    }
});
/* eslint-disable max-len */
/**
 * A React Hook to call to utilize Constructor Browse
 * @param {object} [props.initialBrowseResponse] Initial value for browse results. Results will not be re-fetched on first render if this is provided
 */
/* eslint-enable max-len */
function useBrowseResults(props = {}) {
    const { isFirstRender } = (0, useFirstRender_1.default)();
    const { initialBrowseResponse } = props;
    const contextValue = (0, useCioPlpContext_1.useCioPlpContext)();
    if (!contextValue) {
        throw new Error('useBrowseResults() must be used within a component that is a child of <CioPlp />');
    }
    const { cioClient } = contextValue;
    // Throw error if client is not provided and window is defined (i.e. not SSR)
    if (!cioClient && typeof window !== 'undefined') {
        throw new Error('CioClient required');
    }
    const [filterName, setFilterName] = (0, react_1.useState)();
    const [filterValue, setFilterValue] = (0, react_1.useState)();
    const { getRequestConfigs } = (0, useRequestConfigs_1.default)();
    const [state, dispatch] = (0, react_1.useReducer)(reducer_1.requestReducer, reducer_1.initialState, (defaultState) => (0, reducer_1.initFunction)(defaultState, undefined, initialBrowseResponse));
    const { browse: data, status, message } = state;
    const refetch = () => {
        const requestConfigs = getRequestConfigs();
        const isBrowsePage = (0, utils_1.checkIsBrowsePage)(requestConfigs) || !!initialBrowseResponse;
        const { filterName: currentFilterName, filterValue: currentFilterValue, queryParams: browseParams, } = (0, utils_1.getBrowseParamsFromRequestConfigs)(requestConfigs);
        if (isBrowsePage) {
            setFilterName(currentFilterName);
            setFilterValue(currentFilterValue);
            if (cioClient) {
                fetchBrowseResults(cioClient, currentFilterName, currentFilterValue, browseParams, dispatch);
            }
        }
    };
    // Get browse results for initial query if there is one if not don't ever run this effect again
    (0, react_1.useEffect)(() => {
        if (!initialBrowseResponse || !isFirstRender) {
            refetch();
        }
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, []);
    return {
        status,
        filterName,
        filterValue,
        message,
        data,
        refetch,
    };
}
exports.default = useBrowseResults;
