"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const react_1 = require("react");
const useCioPlpContext_1 = require("./useCioPlpContext");
const useSearchResults_1 = tslib_1.__importDefault(require("./useSearchResults"));
const useFilter_1 = tslib_1.__importDefault(require("./useFilter"));
const useSort_1 = tslib_1.__importDefault(require("./useSort"));
const usePagination_1 = tslib_1.__importDefault(require("./usePagination"));
const utils_1 = require("../utils");
const useBrowseResults_1 = tslib_1.__importDefault(require("./useBrowseResults"));
const useGroups_1 = tslib_1.__importDefault(require("./useGroups"));
const useRequestConfigs_1 = tslib_1.__importDefault(require("./useRequestConfigs"));
function useCioPlp(props = {}) {
    var _a;
    const { initialSearchResponse, initialBrowseResponse, paginationConfigs = {}, sortConfigs = {}, filterConfigs = {}, groupsConfigs = {}, } = props;
    const contextValue = (0, useCioPlpContext_1.useCioPlpContext)();
    if (!contextValue) {
        throw new Error('useCioPlp() must be used within a component that is a child of <CioPlp /> or <CioPlpProvider />');
    }
    const { getRequestConfigs } = (0, useRequestConfigs_1.default)();
    const requestConfigs = getRequestConfigs();
    const isSearchPage = (0, utils_1.checkIsSearchPage)(requestConfigs) || !!initialSearchResponse;
    const isBrowsePage = (0, utils_1.checkIsBrowsePage)(requestConfigs) || !!initialBrowseResponse;
    const search = (0, useSearchResults_1.default)({ initialSearchResponse });
    const browse = (0, useBrowseResults_1.default)({ initialBrowseResponse });
    function coalesceResponse() {
        if (isSearchPage && (0, utils_1.isPlpSearchDataResults)(search === null || search === void 0 ? void 0 : search.data)) {
            return search.data.response;
        }
        if (isBrowsePage && (0, utils_1.isPlpBrowseDataResults)(browse === null || browse === void 0 ? void 0 : browse.data)) {
            return browse.data.response;
        }
        return null;
    }
    const [facets, setFacets] = (0, react_1.useState)(() => { var _a; return ((_a = coalesceResponse()) === null || _a === void 0 ? void 0 : _a.facets) || []; });
    const [sortOptions, setSortOptions] = (0, react_1.useState)(() => { var _a; return ((_a = coalesceResponse()) === null || _a === void 0 ? void 0 : _a.sortOptions) || []; });
    const [totalNumResults, setTotalNumResults] = (0, react_1.useState)(() => { var _a; return ((_a = coalesceResponse()) === null || _a === void 0 ? void 0 : _a.totalNumResults) || 0; });
    const [rawGroups, setGroups] = (0, react_1.useState)(((_a = coalesceResponse()) === null || _a === void 0 ? void 0 : _a.groups) || []);
    const refetch = () => {
        const currentRequestConfigs = getRequestConfigs();
        const pageType = (0, utils_1.getPageType)(currentRequestConfigs);
        switch (pageType) {
            case 'search':
                search.refetch();
                break;
            case 'browse':
                browse.refetch();
                break;
            default:
        }
    };
    (0, react_1.useEffect)(() => {
        if (isSearchPage && (0, utils_1.isPlpSearchDataResults)(search.data)) {
            setFacets(search.data.response.facets);
            setSortOptions(search.data.response.sortOptions);
            setTotalNumResults(search.data.response.totalNumResults);
            setGroups(search.data.response.groups);
        }
        else if (isBrowsePage && (0, utils_1.isPlpBrowseDataResults)(browse.data)) {
            setFacets(browse.data.response.facets);
            setSortOptions(browse.data.response.sortOptions);
            setTotalNumResults(browse.data.response.totalNumResults);
            setGroups(browse.data.response.groups);
        }
    }, [search.data, isSearchPage, browse.data, isBrowsePage]);
    const filters = (0, useFilter_1.default)(Object.assign({ facets }, filterConfigs));
    const sort = (0, useSort_1.default)(Object.assign({ sortOptions }, sortConfigs));
    const pagination = (0, usePagination_1.default)(Object.assign({ totalNumResults }, paginationConfigs));
    const groups = (0, useGroups_1.default)(Object.assign({ groups: rawGroups }, groupsConfigs));
    const data = isSearchPage ? search.data : browse.data;
    const plpContainerCnstrcDataAttributes = (0, utils_1.getPlpContainerCnstrcDataAttributes)(data, requestConfigs);
    return {
        isSearchPage,
        isBrowsePage,
        searchQuery: search.query,
        browseFilterName: browse.filterName,
        browseFilterValue: browse.filterValue,
        status: isSearchPage ? search.status : browse.status,
        data,
        refetch,
        filters,
        sort,
        pagination,
        groups,
        plpContainerCnstrcDataAttributes,
    };
}
exports.default = useCioPlp;
