"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const react_1 = require("react");
const useCioPlpContext_1 = require("./useCioPlpContext");
const useFilter_1 = tslib_1.__importDefault(require("./useFilter"));
const useRequestConfigs_1 = tslib_1.__importDefault(require("./useRequestConfigs"));
const useOptionsList_1 = tslib_1.__importDefault(require("./useOptionsList"));
const useCioBreadcrumb_1 = tslib_1.__importDefault(require("./useCioBreadcrumb"));
function useGroups(props) {
    var _a, _b;
    const { groups, initialNumOptions: numOptionsProps } = props;
    const contextValue = (0, useCioPlpContext_1.useCioPlpContext)();
    if (!contextValue) {
        throw new Error('useGroups must be used within a component that is a child of <CioPlp />');
    }
    const { setFilter } = (0, useFilter_1.default)({ facets: [] });
    const { getRequestConfigs } = (0, useRequestConfigs_1.default)();
    const requestConfigs = getRequestConfigs();
    let groupOptions = groups;
    let currentGroupId = ((_b = (_a = requestConfigs.filters) === null || _a === void 0 ? void 0 : _a.groupId) === null || _b === void 0 ? void 0 : _b.toString()) || null;
    if (currentGroupId || groups.length === 1) {
        currentGroupId = groups[0].groupId;
        groupOptions = groups[0].children;
    }
    const setGroup = (groupId) => {
        setFilter('group_id', groupId);
    };
    const { breadcrumbs, currentPage } = (0, useCioBreadcrumb_1.default)({ groups, filterValue: currentGroupId || 'all' }) || [];
    const { initialNumOptions, isShowAll, setIsShowAll, optionsToRender, setOptionsToRender } = (0, useOptionsList_1.default)({
        options: groupOptions,
        initialNumOptions: numOptionsProps,
    });
    const [selectedGroupId, setSelectedGroupId] = (0, react_1.useState)();
    const onOptionSelect = (groupId) => {
        if (groupId === currentGroupId || groupId === selectedGroupId) {
            setSelectedGroupId(null);
            setGroup(null);
        }
        else {
            setSelectedGroupId(groupId);
            setGroup(groupId);
        }
    };
    const goToGroupFilter = (breadcrumb) => {
        var _a;
        const groupIds = (_a = breadcrumb === null || breadcrumb === void 0 ? void 0 : breadcrumb.path) === null || _a === void 0 ? void 0 : _a.split('/');
        const targetGroupId = groupIds[groupIds.length - 1];
        // If there are no parents, remove the filter entirely.
        // This assumes a one-root-node hierarchy
        if (groupIds.length > 2) {
            onOptionSelect(targetGroupId);
        }
        else {
            onOptionSelect(null);
        }
    };
    return {
        groupOptions,
        setGroup,
        currentGroupId,
        selectedGroupId,
        setSelectedGroupId,
        onOptionSelect,
        goToGroupFilter,
        // useCioBreadcrumbs
        breadcrumbs,
        currentPage,
        // useOptionsList
        initialNumOptions,
        isShowAll,
        setIsShowAll,
        optionsToRender,
        setOptionsToRender,
    };
}
exports.default = useGroups;
