"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const react_1 = require("react");
const transformers_1 = require("../utils/transformers");
const reducer_1 = require("../components/CioPlpGrid/reducer");
const useCioPlpContext_1 = require("./useCioPlpContext");
const useRequestConfigs_1 = tslib_1.__importDefault(require("./useRequestConfigs"));
const utils_1 = require("../utils");
const useFirstRender_1 = tslib_1.__importDefault(require("./useFirstRender"));
const fetchSearchResults = (client, query, searchParams, dispatch) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    dispatch({
        type: reducer_1.RequestStatus.FETCHING,
    });
    try {
        const res = yield client.search.getSearchResults(query, searchParams);
        dispatch({
            type: reducer_1.RequestStatus.SUCCESS,
            requestType: reducer_1.RequestType.SEARCH,
            payload: (0, transformers_1.transformSearchResponse)(res),
        });
    }
    catch (err) {
        if (err instanceof Error) {
            dispatch({
                type: reducer_1.RequestStatus.ERROR,
                payload: err.message,
            });
        }
    }
});
/* eslint-disable max-len */
/**
 * A React Hook to call to utilize Constructor Search
 * @param {Object} [props] - The component props.
 * @param {object} [props.initialSearchResponse] Initial value for search results
 * (Would be useful when passing initial state for the first render from the server
 *  to the client via something like getServerSideProps)
 * @returns {status, data, pagination, refetch}
 */
/* eslint-enable max-len */
function useSearchResults(props = {}) {
    const { isFirstRender } = (0, useFirstRender_1.default)();
    const { initialSearchResponse } = props;
    const contextValue = (0, useCioPlpContext_1.useCioPlpContext)();
    if (!contextValue) {
        throw new Error('useSearchResults() must be used within a component that is a child of <CioPlp />');
    }
    const { cioClient } = contextValue;
    // Throw error if client is not provided and window is defined (i.e. not SSR)
    if (!cioClient && typeof window !== 'undefined') {
        throw new Error('CioClient required');
    }
    const [query, setQuery] = (0, react_1.useState)();
    const { getRequestConfigs } = (0, useRequestConfigs_1.default)();
    const [state, dispatch] = (0, react_1.useReducer)(reducer_1.requestReducer, reducer_1.initialState, (defaultState) => (0, reducer_1.initFunction)(defaultState, initialSearchResponse));
    const { search: data, status, message } = state;
    const refetch = () => {
        const requestConfigs = getRequestConfigs();
        const { query: currentQuery, searchParams } = (0, utils_1.getSearchParamsFromRequestConfigs)(requestConfigs);
        const isSearchPage = (0, utils_1.checkIsSearchPage)(requestConfigs) || !!initialSearchResponse;
        if (isSearchPage) {
            setQuery(currentQuery);
            if (cioClient && currentQuery) {
                fetchSearchResults(cioClient, currentQuery, searchParams, dispatch);
            }
        }
    };
    // Get search results for initial query if there is one if not don't ever run this effect again
    (0, react_1.useEffect)(() => {
        if (!initialSearchResponse || !isFirstRender) {
            refetch();
        }
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, []);
    return {
        query,
        status,
        message,
        data,
        refetch,
    };
}
exports.default = useSearchResults;
