"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const react_1 = require("react");
const useCioPlpContext_1 = require("./useCioPlpContext");
const useRequestConfigs_1 = tslib_1.__importDefault(require("./useRequestConfigs"));
const useSort = ({ sortOptions }) => {
    const contextValue = (0, useCioPlpContext_1.useCioPlpContext)();
    if (!contextValue) {
        throw new Error('useSort must be used within a component that is a child of <CioPlp />');
    }
    const [selectedSort, setSelectedSort] = (0, react_1.useState)(null);
    const { getRequestConfigs, setRequestConfigs } = (0, useRequestConfigs_1.default)();
    const { sortBy, sortOrder } = getRequestConfigs();
    // Read sort configs from url and set state
    (0, react_1.useEffect)(() => {
        const sortOption = sortOptions.find((option) => option.sortBy === sortBy && option.sortOrder === sortOrder);
        if (sortOption)
            setSelectedSort(sortOption);
        // Select default sort option
        else if (sortOptions.length) {
            const defaultSort = sortOptions.find((option) => option.status === 'selected');
            if (defaultSort)
                setSelectedSort(defaultSort);
        }
    }, [sortBy, sortOrder, sortOptions]);
    const changeSelectedSort = (sortOption) => {
        setSelectedSort(sortOption);
        setRequestConfigs({ sortBy: sortOption.sortBy, sortOrder: sortOption.sortOrder, page: 1 });
    };
    return {
        sortOptions,
        selectedSort,
        changeSelectedSort,
    };
};
exports.default = useSort;
