"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getPageType = exports.checkIsBrowsePage = exports.checkIsSearchPage = exports.getBrowseParamsFromRequestConfigs = exports.getSearchParamsFromRequestConfigs = void 0;
const tslib_1 = require("tslib");
const common_1 = require("./common");
function getSearchParamsFromRequestConfigs(requestConfigs) {
    const { query = '', filterValue, filterName } = requestConfigs, rest = tslib_1.__rest(requestConfigs, ["query", "filterValue", "filterName"]);
    const searchParams = (0, common_1.removeNullValuesFromObject)(rest);
    return { query, searchParams };
}
exports.getSearchParamsFromRequestConfigs = getSearchParamsFromRequestConfigs;
function getBrowseParamsFromRequestConfigs(requestConfigs) {
    const { query, filterValue = '', filterName = '' } = requestConfigs, queryParams = tslib_1.__rest(requestConfigs, ["query", "filterValue", "filterName"]);
    return { filterName, filterValue, queryParams: (0, common_1.removeNullValuesFromObject)(queryParams) };
}
exports.getBrowseParamsFromRequestConfigs = getBrowseParamsFromRequestConfigs;
function checkIsSearchPage(requestConfigs) {
    const { query } = getSearchParamsFromRequestConfigs(requestConfigs);
    return !!query;
}
exports.checkIsSearchPage = checkIsSearchPage;
function checkIsBrowsePage(requestConfigs) {
    const { filterName, filterValue } = getBrowseParamsFromRequestConfigs(requestConfigs);
    return !!filterName && !!filterValue;
}
exports.checkIsBrowsePage = checkIsBrowsePage;
function getPageType(requestConfigs) {
    if (checkIsSearchPage(requestConfigs)) {
        return 'search';
    }
    if (checkIsBrowsePage(requestConfigs)) {
        return 'browse';
    }
    return 'unknown';
}
exports.getPageType = getPageType;
