"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getPreferredColorScheme = exports.isHexColor = exports.convertPrimaryColorsToString = exports.rgbToHsl = exports.concatStyles = void 0;
function concatStyles(...classes) {
    return classes.filter(Boolean).join(' ');
}
exports.concatStyles = concatStyles;
function rgbToHsl(r, g, b) {
    const rConverted = r / 255;
    const gConverted = g / 255;
    const bConverted = b / 255;
    const max = Math.max(rConverted, gConverted, bConverted);
    const min = Math.min(rConverted, gConverted, bConverted);
    const delta = max - min;
    let h = 0;
    if (delta === 0)
        h = 0;
    else if (max === rConverted)
        h = ((gConverted - bConverted) / delta) % 6;
    else if (max === gConverted)
        h = (bConverted - rConverted) / delta + 2;
    else if (max === bConverted)
        h = (rConverted - gConverted) / delta + 4;
    const l = (min + max) / 2;
    const s = delta === 0 ? 0 : delta / (1 - Math.abs(2 * l - 1));
    const finalH = Math.round(h * 60);
    const finalS = Math.round(s * 100);
    const finalL = Math.round(l * 100);
    return [finalH, finalS, finalL];
}
exports.rgbToHsl = rgbToHsl;
function convertPrimaryColorsToString(primaryColorStyles) {
    return `{
    --primary-color-h: ${primaryColorStyles['--primary-color-h']}; 
    --primary-color-s: ${primaryColorStyles['--primary-color-s']}; 
    --primary-color-l: ${primaryColorStyles['--primary-color-l']}; 
  }`;
}
exports.convertPrimaryColorsToString = convertPrimaryColorsToString;
function isHexColor(hex) {
    return (typeof hex === 'string' && hex.length === 7 && !Number.isNaN(Number(`0x${hex.substring(1)}`)));
}
exports.isHexColor = isHexColor;
function getPreferredColorScheme() {
    var _a;
    let colorScheme = 'light';
    // Check if the dark-mode Media-Query matches
    if ((_a = window.matchMedia('(prefers-color-scheme: dark)')) === null || _a === void 0 ? void 0 : _a.matches) {
        colorScheme = 'dark';
    }
    return colorScheme;
}
exports.getPreferredColorScheme = getPreferredColorScheme;
