"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.transformBrowseResponse = exports.transformSearchResponse = exports.transformItemGroups = exports.transformResponseSortOptions = exports.transformResponseFacets = exports.transformHierarchicalFacetOptions = exports.transformResultItem = exports.transformResultVariation = void 0;
const tslib_1 = require("tslib");
const typeHelpers_1 = require("./typeHelpers");
function isAPIRedirectSearchResponse(response) {
    return 'redirect' in response;
}
function transformResultVariation(variation, includeRaw = true) {
    const _a = variation.data, { url, image_url: imageUrl, group_ids: groupIds, description, facets, variation_id: variationId } = _a, otherMetadataFields = tslib_1.__rest(_a, ["url", "image_url", "group_ids", "description", "facets", "variation_id"]);
    const transformedVariation = {
        itemName: variation.value,
        // Flatten the data object
        url,
        imageUrl,
        description,
        facets,
        variationId,
        rawResponse: includeRaw ? variation : undefined,
        // Remaining unmapped metadata fields
        data: otherMetadataFields,
    };
    return transformedVariation;
}
exports.transformResultVariation = transformResultVariation;
function transformResultItem(item, includeRaw = true) {
    var _a;
    const _b = item.data, { id: itemId, url, image_url: imageUrl, group_ids: groupIds, description, facets, groups, variation_id: variationId } = _b, otherMetadataFields = tslib_1.__rest(_b, ["id", "url", "image_url", "group_ids", "description", "facets", "groups", "variation_id"]);
    const transformedItem = {
        matchedTerms: item.matched_terms,
        itemName: item.value,
        isSlotted: item.is_slotted,
        labels: item.labels,
        variations: (_a = item.variations) === null || _a === void 0 ? void 0 : _a.map((variation) => transformResultVariation(variation)),
        variationsMap: item.variations_map,
        // Flatten the data object
        itemId,
        url,
        imageUrl,
        groupIds,
        groups,
        description,
        facets,
        variationId,
        rawResponse: includeRaw ? item : undefined,
        // Remaining unmapped metadata fields
        data: otherMetadataFields,
    };
    return transformedItem;
}
exports.transformResultItem = transformResultItem;
function transformHierarchicalFacetOptions(facetOptions) {
    if (facetOptions.length === 0)
        return [];
    const transformedOptions = facetOptions.map((option) => {
        const { display_name: displayName, data, options } = option, otherFields = tslib_1.__rest(option, ["display_name", "data", "options"]);
        const { parent_value: parentValue } = data, otherDataFields = tslib_1.__rest(data, ["parent_value"]);
        return Object.assign(Object.assign({}, otherFields), { data: Object.assign(Object.assign({}, otherDataFields), { parentValue }), displayName, options: transformHierarchicalFacetOptions(options) });
    });
    return transformedOptions;
}
exports.transformHierarchicalFacetOptions = transformHierarchicalFacetOptions;
function transformResponseFacets(facets) {
    return facets.map((facet) => {
        const { display_name: displayName, name, type, data, hidden, min, max, status, options, } = facet;
        const transformedFacet = {
            displayName,
            name,
            type,
            data,
            hidden,
        };
        if ((0, typeHelpers_1.isRangeFacet)(transformedFacet)) {
            transformedFacet.min = min;
            transformedFacet.max = max;
            transformedFacet.status = status;
        }
        if ((0, typeHelpers_1.isOptionFacet)(transformedFacet)) {
            transformedFacet.options = options.map((option) => {
                const transformedFacetOption = {
                    status: option.status,
                    count: option.count,
                    displayName: option.display_name,
                    value: option.value,
                    data: option.data,
                };
                if (option.range) {
                    transformedFacetOption.range = option.range;
                }
                if (option.options) {
                    const _a = option.data, { parent_value: parentValue } = _a, otherDataFields = tslib_1.__rest(_a, ["parent_value"]);
                    transformedFacetOption.data = Object.assign(Object.assign({}, otherDataFields), { parentValue });
                    transformedFacetOption.options = transformHierarchicalFacetOptions(option.options);
                }
                return transformedFacetOption;
            });
        }
        return transformedFacet;
    });
}
exports.transformResponseFacets = transformResponseFacets;
function transformResponseSortOptions(options) {
    if (options) {
        return options.map((option) => ({
            sortBy: option.sort_by,
            sortOrder: option.sort_order,
            displayName: option.display_name,
            status: option.status,
        }));
    }
    return [];
}
exports.transformResponseSortOptions = transformResponseSortOptions;
function transformItemGroups(groups) {
    if (groups) {
        return groups.map((itemGroup) => ({
            groupId: itemGroup.group_id,
            displayName: itemGroup.display_name,
            count: itemGroup.count,
            data: itemGroup.data,
            children: transformItemGroups(itemGroup.children),
            parents: transformItemGroups(itemGroup.parents),
        }));
    }
    return [];
}
exports.transformItemGroups = transformItemGroups;
function transformSearchResponse(res) {
    const { response, request, result_id: resultId } = res;
    if (!response || !request)
        return null;
    if (isAPIRedirectSearchResponse(response)) {
        return {
            resultId,
            request,
            redirect: response.redirect,
            rawApiResponse: res,
        }; // Type override due to partials in client-js
    }
    return {
        resultId,
        request,
        rawApiResponse: res,
        response: {
            totalNumResults: response.total_num_results,
            numResultsPerPage: request.num_results_per_page,
            results: response.results.map((result) => transformResultItem(result, false)),
            facets: transformResponseFacets(response.facets),
            groups: transformItemGroups(response.groups),
            sortOptions: transformResponseSortOptions(response.sort_options),
            refinedContent: response.refined_content,
        },
    }; // Type override due to partials in client-js
}
exports.transformSearchResponse = transformSearchResponse;
function transformBrowseResponse(res) {
    const { response, request, result_id: resultId } = res;
    if (!response || !request)
        return null;
    return {
        resultId,
        request,
        rawApiResponse: res,
        response: {
            totalNumResults: response.total_num_results,
            numResultsPerPage: request.num_results_per_page,
            results: response.results.map((result) => transformResultItem(result, false)),
            facets: transformResponseFacets(response.facets),
            groups: transformItemGroups(response.groups),
            sortOptions: transformResponseSortOptions(response.sort_options),
            refinedContent: response.refined_content,
        },
    }; // Type override due to partials in client-js
}
exports.transformBrowseResponse = transformBrowseResponse;
