"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getUrlFromState = exports.getStateFromUrl = exports.getFilterParamsFromState = exports.extractFiltersFromUrl = exports.setUrl = exports.getUrl = exports.defaultQueryStringMap = void 0;
const tslib_1 = require("tslib");
exports.defaultQueryStringMap = Object.freeze({
    query: 'q',
    page: 'page',
    offset: 'offset',
    resultsPerPage: 'numResults',
    filters: 'filters',
    sortBy: 'sortBy',
    sortOrder: 'sortOrder',
    section: 'section',
});
function getUrl() {
    if (typeof window === 'undefined')
        return undefined;
    return window.location.href;
}
exports.getUrl = getUrl;
function setUrl(newUrlWithEncodedState) {
    if (typeof window === 'undefined')
        return;
    window.location.href = newUrlWithEncodedState;
}
exports.setUrl = setUrl;
function extractFiltersFromUrl(urlParams) {
    const filters = {};
    const filterRegex = new RegExp(`^${exports.defaultQueryStringMap.filters}\\[(.*)\\]`);
    urlParams === null || urlParams === void 0 ? void 0 : urlParams.forEach((value, key) => {
        var _a;
        const filterKey = (_a = key === null || key === void 0 ? void 0 : key.match(filterRegex)) === null || _a === void 0 ? void 0 : _a[1];
        if (filterKey) {
            if (filters[filterKey]) {
                filters[filterKey].push(value);
            }
            else {
                filters[filterKey] = [value];
            }
        }
    });
    return Object.keys(filters).length ? filters : undefined;
}
exports.extractFiltersFromUrl = extractFiltersFromUrl;
function getFilterParamsFromState(urlParams, filters) {
    var _a;
    if (filters) {
        (_a = Object.entries(filters)) === null || _a === void 0 ? void 0 : _a.forEach(([filterName, filterValues]) => {
            if (Array.isArray(filterValues)) {
                filterValues.forEach((filterValue) => {
                    urlParams.append(`filters[${filterName}]`, String(filterValue));
                });
            }
            else {
                urlParams.append(`filters[${filterName}]`, String(filterValues));
            }
        });
    }
}
exports.getFilterParamsFromState = getFilterParamsFromState;
function getStateFromUrl(url) {
    var _a;
    const urlObject = new URL(url);
    const urlParams = urlObject.searchParams;
    const paths = (_a = decodeURI(urlObject === null || urlObject === void 0 ? void 0 : urlObject.pathname)) === null || _a === void 0 ? void 0 : _a.split('/');
    let filterName;
    let filterValue;
    if (paths.length > 0) {
        filterName = 'group_id';
        filterValue = paths[paths.length - 1];
    }
    const rawState = {};
    Object.entries(exports.defaultQueryStringMap).forEach(([key, val]) => {
        const storedVal = urlParams.get(val);
        if (storedVal != null) {
            rawState[key] = storedVal;
        }
    });
    const filters = extractFiltersFromUrl(urlParams);
    const { page, offset, resultsPerPage, fmtOptions, hiddenFacets, hiddenFields, variationsMap, preFilterExpression } = rawState, rest = tslib_1.__rest(rawState, ["page", "offset", "resultsPerPage", "fmtOptions", "hiddenFacets", "hiddenFields", "variationsMap", "preFilterExpression"]);
    const state = Object.assign({}, rest);
    if (page)
        state.page = Number(page);
    if (offset)
        state.offset = Number(offset);
    if (resultsPerPage)
        state.resultsPerPage = Number(resultsPerPage);
    if (filters)
        state.filters = filters;
    if (filterName) {
        state.filterName = filterName;
        state.filterValue = filterValue;
    }
    return state;
}
exports.getStateFromUrl = getStateFromUrl;
function getUrlFromState(state, url) {
    const urlObject = new URL(url);
    let { pathname } = urlObject;
    if (state.filterName && state.filterValue) {
        if (pathname.match(/(group_id|collection_id)\/[^/]+$/)) {
            pathname = pathname.replace(/\/(group_id|collection_id)\/[^/]+$/, `/${state.filterName}/${state.filterValue}`);
        }
        else {
            pathname = `/${state.filterName}/${state.filterValue}`;
        }
    }
    const params = new URLSearchParams();
    Object.entries(state).forEach(([key, val]) => {
        if (exports.defaultQueryStringMap[key] === undefined) {
            return;
        }
        let encodedVal = '';
        if (key === 'filters' && state.filters) {
            getFilterParamsFromState(params, state.filters);
        }
        else if (typeof val !== 'string') {
            encodedVal = JSON.stringify(val);
        }
        else {
            encodedVal = val;
        }
        if (encodedVal) {
            params.set(exports.defaultQueryStringMap[key], encodedVal);
        }
    });
    return `${urlObject.origin}${pathname}?${params.toString()}`;
}
exports.getUrlFromState = getUrlFromState;
