import React from 'react';
import { useCioPlpContext } from '../../hooks/useCioPlpContext';
import { useOnAddToCart, useOnProductCardClick } from '../../hooks/callbacks';
import ProductSwatch from '../ProductSwatch';
import useProductInfo from '../../hooks/useProduct';
import { getProductCardCnstrcDataAttributes } from '../../utils';
/**
 * ProductCard component that has Constructor tracking built-in.
 */
export default function ProductCard(props) {
    const { item, children } = props;
    const state = useCioPlpContext();
    const productInfo = useProductInfo({ item });
    const { productSwatch, itemName, itemPrice, itemImageUrl, itemUrl } = productInfo;
    if (!state) {
        throw new Error('This component is meant to be used within the CioPlp provider.');
    }
    if (!item.data || !item.itemId || !item.itemName) {
        throw new Error('data, itemId, or itemName are required.');
    }
    const client = state.cioClient;
    const onAddToCart = useOnAddToCart(client, state.callbacks.onAddToCart);
    const { formatPrice } = state.formatters;
    const onClick = useOnProductCardClick(client, state.callbacks.onProductCardClick);
    const cnstrcData = getProductCardCnstrcDataAttributes(productInfo);
    return (React.createElement(React.Fragment, null, typeof children === 'function' ? (children({
        item,
        productInfo,
        formatPrice,
        onAddToCart,
        onClick,
        productCardCnstrcDataAttributes: cnstrcData,
    })) : (React.createElement("a", { ...cnstrcData, className: 'cio-product-card', href: itemUrl, onClick: (e) => onClick(e, item, productSwatch?.selectedVariation?.variationId) },
        React.createElement("div", { className: 'cio-image-container' },
            React.createElement("img", { alt: itemName, src: itemImageUrl, className: 'cio-image' })),
        React.createElement("div", { className: 'cio-content' },
            Number(itemPrice) >= 0 && (React.createElement("div", { className: 'cio-item-price' }, formatPrice(itemPrice))),
            React.createElement("div", { className: 'cio-item-name' }, itemName),
            productSwatch && React.createElement(ProductSwatch, { swatchObject: productSwatch })),
        React.createElement("button", { className: 'cio-add-to-cart-button', type: 'button', onClick: (e) => onAddToCart(e, item, itemPrice, productSwatch?.selectedVariation?.variationId) }, "Add to Cart")))));
}
