import React from 'react';
import { CnstrcData, IncludeRenderProps, Item, ProductInfoObject } from '../../types';
interface Props {
    /**
     * Constructor's Transformed API Item Object.
     */
    item: Item;
}
/**
 * Props that will be passed to the renderProps function
 */
export interface ProductCardRenderProps extends ProductCardProps {
    /**
     * Function to format the price. Defaults to "$0.00".
     * Set globally at the CioPlp provider level.
     */
    formatPrice: (price: number) => string;
    /**
     * Object containing information about the current product, variation
     */
    productInfo: ProductInfoObject;
    /**
     * Callback to run on add-to-cart event.
     * Set globally at the CioPlp provider level.
     */
    onAddToCart: (event: React.MouseEvent, item: Item, revenue: number, selectedVariation: string) => void;
    /**
     * Callback to run on Product Card Click.
     * Set globally at the CioPlp provider level.
     */
    onClick: (event: React.MouseEvent, item: Item) => void;
    /**
     * Data Attributes to surface on parent div of product card.
     */
    productCardCnstrcDataAttributes: CnstrcData;
}
export type ProductCardProps = IncludeRenderProps<Props, ProductCardRenderProps>;
/**
 * ProductCard component that has Constructor tracking built-in.
 */
export default function ProductCard(props: ProductCardProps): React.JSX.Element;
export {};
