import { PlpContextValue, PlpItemGroup } from '../types';
import { UseSearchResultsProps } from './useSearchResults';
import { UseFilterProps } from './useFilter';
import { UseSortProps } from './useSort';
import { UsePaginationProps } from './usePagination';
import { UseBrowseResultsProps } from './useBrowseResults';
import { UseGroupProps } from './useGroups';
export interface UseCioPlpHook extends PlpContextValue {
}
export type UseCioPlpProps = UseSearchResultsProps & UseBrowseResultsProps & {
    /**
     * Used to set `windowSize` of `pages` array. Can also override `resultsPerPage` set at the Provider-level.
     */
    paginationConfigs?: Omit<UsePaginationProps, 'totalNumResults'>;
    /**
     * No configurations available yet.
     */
    sortConfigs?: Omit<UseSortProps, 'sortOptions'>;
    /**
     * No configurations available yet.
     */
    filterConfigs?: Omit<UseFilterProps, 'facets'>;
    /**
     * Used to set the `initialNumOptions` to limit the number of options shown initially.
     */
    groupsConfigs?: Omit<UseGroupProps, 'groups'>;
};
export default function useCioPlp(props?: UseCioPlpProps): {
    isSearchPage: boolean;
    isBrowsePage: boolean;
    searchQuery: string | undefined;
    browseFilterName: string | undefined;
    browseFilterValue: string | undefined;
    status: import("../components/CioPlpGrid").RequestStatus | null;
    data: import("../types").PlpSearchDataResults | import("../types").PlpSearchDataRedirect | import("../types").PlpBrowseData | null;
    refetch: () => void;
    filters: import("./useFilter").UseFilterReturn;
    sort: import("../types").UseSortReturn;
    pagination: import("./usePagination").UsePaginationReturn;
    groups: {
        groupOptions: PlpItemGroup[];
        setGroup: (groupId: string | null) => void;
        currentGroupId: string | null;
        selectedGroupId: string | null | undefined;
        setSelectedGroupId: import("react").Dispatch<import("react").SetStateAction<string | null | undefined>>;
        onOptionSelect: (groupId: string | null) => void;
        goToGroupFilter: (breadcrumb: import("./useCioBreadcrumb").Breadcrumb) => void;
        breadcrumbs: import("./useCioBreadcrumb").Breadcrumb[];
        currentPage: string | undefined;
        initialNumOptions: number;
        isShowAll: boolean;
        setIsShowAll: import("react").Dispatch<import("react").SetStateAction<boolean>>;
        optionsToRender: PlpItemGroup[];
        setOptionsToRender: import("react").Dispatch<import("react").SetStateAction<PlpItemGroup[]>>;
    };
    plpContainerCnstrcDataAttributes: Record<`data-cnstrc-${string}`, string | number | boolean>;
};
